@@ -57,7 +57,8 @@ enum
   PROP_0,
   PROP_GST_SINK,
   PROP_GST_SRC,
-  PROP_COMPONENTS
+  PROP_COMPONENTS,
+  PROP_DO_TIMESTAMP,
 };
 
 struct _FsShmTransmitterPrivate
@@ -71,6 +72,8 @@ struct _FsShmTransmitterPrivate
   /* They are tables of pointers, one per component */
   GstElement **funnels;
   GstElement **tees;
+
+  gboolean do_timestamp;
 };
 
 #define FS_SHM_TRANSMITTER_GET_PRIVATE(o)  \
@@ -266,6 +269,8 @@ fs_shm_transmitter_class_init (FsShmTransmitterClass *klass)
   g_object_class_override_property (gobject_class, PROP_GST_SINK, "gst-sink");
   g_object_class_override_property (gobject_class, PROP_COMPONENTS,
     "components");
+  g_object_class_override_property (gobject_class, PROP_DO_TIMESTAMP,
+    "do-timestamp");
 
   transmitter_class->new_stream_transmitter =
     fs_shm_transmitter_new_stream_transmitter;
@@ -286,6 +291,7 @@ fs_shm_transmitter_init (FsShmTransmitter *self)
   self->priv = FS_SHM_TRANSMITTER_GET_PRIVATE (self);
 
   self->components = 2;
+  self->priv->do_timestamp = TRUE;
 }
 
 static void
@@ -489,6 +495,9 @@ fs_shm_transmitter_get_property (GObject *object,
     case PROP_COMPONENTS:
       g_value_set_uint (value, self->components);
       break;
+    case PROP_DO_TIMESTAMP:
+      g_value_set_boolean (value, self->priv->do_timestamp);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -507,6 +516,9 @@ fs_shm_transmitter_set_property (GObject *object,
     case PROP_COMPONENTS:
       self->components = g_value_get_uint (value);
       break;
+    case PROP_DO_TIMESTAMP:
+      self->priv->do_timestamp = g_value_get_boolean (value);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -607,7 +619,7 @@ fs_shm_transmitter_get_shm_src (FsShmTransmitter *self,
 
   g_object_set (elem,
       "socket-path", path,
-      "do-timestamp", TRUE,
+      "do-timestamp", self->priv->do_timestamp,
       "is-live", TRUE,
       NULL);
 
@@ -732,7 +744,6 @@ ShmSink *
 fs_shm_transmitter_get_shm_sink (FsShmTransmitter *self,
     guint component,
     const gchar *path,
-    guint64 buffer_time,
     ready ready_func,
     connection connected_func,
     gpointer cb_data,
@@ -768,17 +779,6 @@ fs_shm_transmitter_get_shm_sink (FsShmTransmitter *self,
       "sync" , FALSE,
       NULL);
 
-  if (g_object_class_find_property (G_OBJECT_GET_CLASS (elem), "buffer-time"))
-  {
-    GST_DEBUG ("Configured shmsink with a %"G_GUINT64_FORMAT" buffer-time",
-      buffer_time);
-    g_object_set (elem, "buffer-time", buffer_time, NULL);
-  }
-  else
-  {
-    GST_DEBUG ("No buffer-time property in shmsink, not setting");
-  }
-
   if (ready_func)
     g_signal_connect (self->priv->gst_sink, "ready", G_CALLBACK (ready_cb),
         shm);
